@@ -13,7 +13,7 @@ from transformers import (
     set_seed,
 )
 from transformers.trainer_utils import get_last_checkpoint
-    
+
 
 class Trainer:
     def __init__(self, arguments):
@@ -39,7 +39,7 @@ class Trainer:
                 self.arguments.model_name_or_path)
             if self.arguments.mode == "seq2seq":
                 print("Training seq2seq language model")
-            elif  self.arguments.mode == "clm":
+            elif self.arguments.mode == "clm":
                 print("Training causal language model")
             else:
                 print("Set TrainingArguments.mode to", self.arguments.mode)
@@ -124,13 +124,14 @@ class Trainer:
             if nproc > 1:
                 rank = torch.distributed.get_rank()
                 print("Distributed setting: rank", rank, "of", nproc)
-                self.raw_datasets = self.raw_datasets.shard(num_shards=nproc, index=rank)
+                self.raw_datasets = self.raw_datasets.shard(
+                    num_shards=nproc, index=rank)
         except Exception as e:
             print("No sharding of dataset:", e)
-                
+
     def GradCheckpoint(self):
         self.arguments.gradient_checkpointing = True
-        
+
     def FreezeEmbeds(self):
         self.freeze(embeddings=True)
 
@@ -141,7 +142,7 @@ class Trainer:
     def unfreeze_params(self, module):
         for par in module.parameters():
             par.requires_grad = True
-            
+
     def get_embedding_layers(self):
         embedding_layers = []
         try:
@@ -161,16 +162,16 @@ class Trainer:
     def freeze(self, encoder=None, decoder=None, embeddings=None):
         if encoder:
             self.freeze_params(self.model.encoder)
-        elif encoder==False:
+        elif encoder == False:
             self.unfreeze_params(self.model.encoder)
         if decoder:
             self.freeze_params(self.model.decoder)
-        elif decoder==False:
+        elif decoder == False:
             self.unfreeze_params(self.model.decoder)
         for el in self.get_embedding_layers():
             if embeddings:
                 self.freeze_params(el)
-            elif embeddings==False:
+            elif embeddings == False:
                 self.unfreeze_params(el)
 
     def resize_token_embeddings_layer(self, round_up=True):
@@ -303,7 +304,7 @@ class Trainer:
                 from_tf=bool(".ckpt" in self.arguments.model_name_or_path),
                 config=self.config,
                 cache_dir=self.arguments.cache_dir,
-                low_cpu_mem_usage=True
+                low_cpu_mem_usage=self.arguments.load_model_low_ram
             )
         elif self.arguments.mode == "clm":
             self.model = transformers.AutoModelForCausalLM.from_pretrained(
@@ -311,14 +312,14 @@ class Trainer:
                 from_tf=bool(".ckpt" in self.arguments.model_name_or_path),
                 config=self.config,
                 cache_dir=self.arguments.cache_dir,
-                low_cpu_mem_usage=True
+                low_cpu_mem_usage=self.arguments.load_model_low_ram
             )
         else:
             print("Model name:", self.arguments.model_name_or_path)
             print("Training mode:", self.arguments.mode)
             NotImplementedError(
                 "Unable to load this type of model for this training mode")
-            
+
         if self.arguments.model_parallel_gpus > 1:
             print("Model parallel on", self.arguments.model_parallel_gpus, "GPU:")
             device_map = {}
